@@ -15,7 +15,7 @@ results <- data.frame(matrix(rep(0,18*(num.var-1)),ncol=18))
 names(results) <- c("Item/Cluster", "Item/Clust","similarity","correlation","alpha1","alpha2",
 "beta1","beta2","size1","size2","rbar1","rbar2","r1","r2","alpha","beta","rbar","size")
 rownames(results) <- paste("C",1:(num.var-1),sep="")
-
+digits <- ICLUST.options$digits
 clusters <- diag(1,nrow =nrow(r.mat))    #original cluster structure is 1 item clusters
 rownames(clusters) <- rownames(r.mat)
 colnames(clusters) <- paste("V",1:num.var,sep="")
@@ -31,7 +31,7 @@ count=1
 while (keep.clustering) {   #loop until we figure out we should stop
 #find similiarities
  #we will do most of the work on a copy of the r.mat
-cluster.stats <- cluster.cor(clusters,r.mat,FALSE)  
+cluster.stats <- cluster.cor(clusters,r.mat,FALSE,digits=9)  
 sim.mat <- cluster.stats$cor    #the correlation matrix
 diag(sim.mat) <- 0   #we don't want 1's on the diagonal to mess up the maximum 
 
@@ -180,15 +180,15 @@ if (ICLUST.options$alpha>0) { #should we apply any tests?
 if (ICLUST.options$alpha.size < min(size1,size2)) {
   switch(ICLUST.options$alpha, {if (alpha < min(alpha1,alpha2)) {if (output>2) {print(
   paste ('do not combine ', cluster.names[max.row],"with", cluster.names[max.col],
-  'new alpha =', round (alpha,2),'old alpha1 =',round( alpha1,2),"old alpha2 =",round(alpha2,2)))}
+  'new alpha =', round (alpha,digits),'old alpha1 =',round( alpha1,digits),"old alpha2 =",round(alpha2,digits)))}
 												test.alpha <- FALSE }},
   {if (alpha < mean(alpha1,alpha2)) {if (output>2) {print(paste ('do not combine ',
-  cluster.names[max.row],"with", cluster.names[max.col],'new alpha =', round (alpha,2),
-  'old alpha1 =',round( alpha1,2),"old alpha2 =",round(alpha2,2)))}
+  cluster.names[max.row],"with", cluster.names[max.col],'new alpha =', round (alpha,digits),
+  'old alpha1 =',round( alpha1,digits),"old alpha2 =",round(alpha2,digits)))}
 												test.alpha <- FALSE  }},
   {if (alpha < max(alpha1,alpha2)) {if (output>2) {print(paste ('do not combine ',
-  cluster.names[max.row],"with", cluster.names[max.col],'new alpha =', round (alpha,2),
-  'old alpha1 =',round( alpha1,2),"old alpha2 =",round(alpha2,2)))}
+  cluster.names[max.row],"with", cluster.names[max.col],'new alpha =', round (alpha,digits),
+  'old alpha1 =',round( alpha1,digits),"old alpha2 =",round(alpha2,digits)))}
 												test.alpha <- FALSE  }}) #end switch  
   }   #end if options$alpha.size
   }
@@ -199,15 +199,15 @@ if (ICLUST.options$beta>0) { #should we apply any tests?
 if (ICLUST.options$beta.size < min(size1,size2)) {
   switch(ICLUST.options$beta, {if (beta.combined < min(beta1,beta2)) {if (output>2) {print(
   paste ('do not combine ', cluster.names[max.row],"with", cluster.names[max.col],'new beta =',
-  round (beta.combined,2),'old beta1 =',round( beta1,2),"old beta2 =",round(beta2,2)))}
+  round (beta.combined,digits),'old beta1 =',round( beta1,digits),"old beta2 =",round(beta2,digits)))}
 												test.beta <- FALSE }},
   {if (beta.combined < mean(beta1,beta2)) {if (output>2) {print(paste ('do not combine ', 
-  cluster.names[max.row],"with", cluster.names[max.col],'new beta =', round (beta.combined,2),
-  'old beta1 =',round( beta1,2),"old beta2 =",round(beta2,2)))}
+  cluster.names[max.row],"with", cluster.names[max.col],'new beta =', round (beta.combined,digits),
+  'old beta1 =',round( beta1,digits),"old beta2 =",round(beta2,digits)))}
 												test.beta <- FALSE  }},
   {if (beta.combined < max(beta1,beta2)) {if (output>2) {print(paste ('do not combine ',
-  cluster.names[max.row],"with", cluster.names[max.col],'new beta =', round (beta.combined,2),
-  'old beta1 =',round( beta1,2),"old beta2 =",round(beta2,2)))}
+  cluster.names[max.row],"with", cluster.names[max.col],'new beta =', round (beta.combined,digits),
+  'old beta1 =',round( beta1,digits),"old beta2 =",round(beta2,digits)))}
 												test.beta <- FALSE  }}) #end switch  
 												
   }   #end if options$beta.size
@@ -262,7 +262,8 @@ results[count,"beta"] <- beta.combined
 results[count,'alpha'] <- alpha
 results[count,'rbar'] <- rbar
 results[count,"size"] <- size12
-results[count,3:18] <- round(results[count,3:18],ICLUST.options$digits)
+#results[count,3:18] <- round(results[count,3:18],ICLUST.options$digits)
+results[count,3:18] <- results[count,3:18]
 #update
 cluster.names[max.row] <- paste("C",count,sep="")
 colnames(clusters) <- cluster.names
@@ -275,7 +276,7 @@ cluster.names <- colnames(clusters)
 
 	}  #end of combine section
 
-if(output > 1) print(results[count,],digits=2)
+if(output > 1) print(results[count,],digits=digits)
 count=count+1 
 if ((num.var - count) < ICLUST.options$n.clus) {keep.clustering <- FALSE}
 if(num.var - count < 1) {keep.clustering <- FALSE}   #only one cluster left
