@@ -3,10 +3,12 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
     {
     lty = "solid"
     all.stats <- describe(x)
-        min.x <- min(all.stats$min)
-   		max.x <- max(all.stats$max)
-    	max.se <- max(all.stats$se)
-    if(is.null(ylim)) {ylim=c(min.x - 2*max.se,max.x+2*max.se)}
+        min.x <- min(all.stats$min,na.rm=TRUE)
+   		max.x <- max(all.stats$max,na.rm=TRUE)
+    	max.se <- max(all.stats$se,na.rm=TRUE)
+    if(is.null(ylim)) {if(is.na(max.x) | is.na(max.se) | is.na(min.x) | is.infinite(max.x)| is.infinite(min.x) | is.infinite(max.se)) {
+                        ylim=c(0,1)} else {
+    ylim=c(min.x - 2*max.se,max.x+2*max.se)}}
     if(is.null(main)) main <- paste(1-alpha,"% confidence limits",sep="")
     
     if (bars) { #draw a bar plot and add error bars -- this is ugly but some people like it
@@ -31,7 +33,7 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
     	 	 xse  <- group.se[i,j]
     	 	ci <- qt(1-alpha,group.n[i,j])
     	 	
-       if(xse>0)    arrows(mp[j,i],xcen-ci*xse,mp[j,i],xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
+       if(is.finite(xse) && xse>0)    arrows(mp[j,i],xcen-ci*xse,mp[j,i],xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
           }} } else {
            if (is.null(xlab)) xlab <- "Grouping Variable"
            mp <- barplot(group.means,beside=TRUE,ylab=ylab,xlab=xlab,ylim=ylim,main=main)
@@ -40,7 +42,7 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
          	 xcen <- group.means[i,j]
     	 	 xse  <- group.se[i,j]
     	 	ci <- qt(1-alpha,group.n[i,j])
-        if(xse>0)     arrows(mp[i,j],xcen-ci*xse,mp[i,j],xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
+        if(is.finite(xse) && xse>0)     arrows(mp[i,j],xcen-ci*xse,mp[i,j],xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
           }} }
          
          
@@ -82,7 +84,7 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
     	 xse  <- x.stats$se[i]
     	# yse <-  y$se[i]
     	 ci <- qt(1-alpha,x.stats$n[i])
-    	  if(xse>0)  arrows(i,xcen-ci*xse,i,xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
+    	  if(is.finite(xse) & xse>0)  arrows(i,xcen-ci*xse,i,xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
     	 
     	#text(xcen,i,labels=lab[i],pos=pos[i],cex=1,offset=arrow.len+1)     #puts in labels for all points
     	}
